searchNodes=[{"doc":"Facilities for tightening loosey goosey types.","ref":"Uptight.html","title":"Uptight","type":"module"},{"doc":"","ref":"Uptight.html#into_text_or_urlsafe/1","title":"Uptight.into_text_or_urlsafe/1","type":"function"},{"doc":"","ref":"Uptight.html#tighten/1","title":"Uptight.tighten/1","type":"function"},{"doc":"This module contains a set of assertion functions that are imported by default into your test cases. In general, a developer will want to use the general assert macro in tests. This macro introspects your code and provides good reporting whenever there is a failure. For example, assert some_fun() == 10 will fail (assuming some_fun() returns 13 ): Comparison ( using == ) failed in : code : assert some_fun ( ) == 10 left : 13 right : 10 This module also provides other convenience functions like assert_in_delta and assert_raise to easily handle other common cases such as checking a floating-point number or handling exceptions.","ref":"Uptight.Assertions.html","title":"Uptight.Assertions","type":"module"},{"doc":"Asserts its argument is a truthy value. assert introspects the underlying expression and provides good reporting whenever there is a failure. For example, if the expression uses the comparison operator, the message will show the values of the two sides. The assertion assert 1 + 2 + 3 + 4 &gt; 15 will fail with the message: Assertion with &gt; failed code : assert 1 + 2 + 3 + 4 &gt; 15 left : 10 right : 15 Similarly, if a match expression is given, it will report any failure in terms of that match. Given assert [ 1 ] = [ 2 ] you'll see: match ( = ) failed code : assert [ 1 ] = [ 2 ] left : [ 1 ] right : [ 2 ] Keep in mind that assert does not change its semantics based on the expression. In other words, the expression is still required to return a truthy value. For example, the following will fail: assert nil = some_function_that_returns_nil ( ) Even though the match works, assert still expects a truth value. In such cases, simply use Kernel.==/2 or Kernel.match?/2 .","ref":"Uptight.Assertions.html#assert/1","title":"Uptight.Assertions.assert/1","type":"macro"},{"doc":"Asserts value is truthy, displaying the given message otherwise. Examples assert false , &quot;it will never be true&quot; assert x == :foo , &quot;expected x to be foo&quot; assert match? ( { :ok , _ } , x ) , &quot;expected x to match {:ok, _}&quot;","ref":"Uptight.Assertions.html#assert/2","title":"Uptight.Assertions.assert/2","type":"function"},{"doc":"Asserts that value1 and value2 differ by no more than delta . This difference is inclusive, so the test will pass if the difference and the delta are equal. Examples assert_in_delta 1.1 , 1.5 , 0.2 assert_in_delta 10 , 15 , 2 assert_in_delta 10 , 15 , 5","ref":"Uptight.Assertions.html#assert_in_delta/4","title":"Uptight.Assertions.assert_in_delta/4","type":"function"},{"doc":"Asserts the exception is raised during function execution. Returns the rescued exception, fails otherwise. Examples assert_raise ArithmeticError , fn -&gt; 1 + &quot;test&quot; end","ref":"Uptight.Assertions.html#assert_raise/2","title":"Uptight.Assertions.assert_raise/2","type":"function"},{"doc":"Asserts the exception is raised during function execution with the expected message , which can be a Regex or an exact String . Returns the rescued exception, fails otherwise. Examples assert_raise ArithmeticError , &quot;bad argument in arithmetic expression&quot; , fn -&gt; 1 + &quot;test&quot; end assert_raise RuntimeError , ~r/^today&#39;s lucky number is 0 \\. \\d +!$/ , fn -&gt; raise &quot;today&#39;s lucky number is \#{ :rand . uniform ( ) } !&quot; end","ref":"Uptight.Assertions.html#assert_raise/3","title":"Uptight.Assertions.assert_raise/3","type":"function"},{"doc":"Asserts that a message matching pattern was or is going to be received within the timeout period, specified in milliseconds. Unlike assert_received , it has a default timeout of 100 milliseconds. The pattern argument must be a match pattern. Flunks with failure_message if a message matching pattern is not received. Examples assert_receive :hello Asserts against a larger timeout: assert_receive :hello , 20_000 You can also match against specific patterns: assert_receive { :hello , _ } x = 5 assert_receive { :count , ^ x }","ref":"Uptight.Assertions.html#assert_receive/3","title":"Uptight.Assertions.assert_receive/3","type":"macro"},{"doc":"Asserts that a message matching pattern was received and is in the current process' mailbox. The pattern argument must be a match pattern. Flunks with failure_message if a message matching pattern was not received. Timeout is set to 0, so there is no waiting time. Examples send ( self ( ) , :hello ) assert_received :hello send ( self ( ) , :bye ) assert_received :hello , &quot;Oh No!&quot; ** (Uptight.AssertionError) Oh No! You can also match against specific patterns: send ( self ( ) , { :hello , &quot;world&quot; } ) assert_received { :hello , _ }","ref":"Uptight.Assertions.html#assert_received/2","title":"Uptight.Assertions.assert_received/2","type":"macro"},{"doc":"Asserts expression will cause an error. Returns the error or fails otherwise. Examples assert catch_error ( error ( 1 ) ) == 1","ref":"Uptight.Assertions.html#catch_error/1","title":"Uptight.Assertions.catch_error/1","type":"macro"},{"doc":"Asserts expression will exit. Returns the exit status/message of the current process or fails otherwise. Examples assert catch_exit ( exit ( 1 ) ) == 1 To assert exits from linked processes started from the test, trap exits with Process.flag/2 and assert the exit message with assert_receive/2 . Process . flag ( :trap_exit , true ) pid = spawn_link ( fn -&gt; Process . exit ( self ( ) , :normal ) end ) assert_receive { :EXIT , ^ pid , :normal }","ref":"Uptight.Assertions.html#catch_exit/1","title":"Uptight.Assertions.catch_exit/1","type":"macro"},{"doc":"Asserts expression will throw a value. Returns the thrown value or fails otherwise. Examples assert catch_throw ( throw ( 1 ) ) == 1","ref":"Uptight.Assertions.html#catch_throw/1","title":"Uptight.Assertions.catch_throw/1","type":"macro"},{"doc":"Fails with a message. Examples flunk ( &quot;This should raise an error&quot; )","ref":"Uptight.Assertions.html#flunk/1","title":"Uptight.Assertions.flunk/1","type":"function"},{"doc":"A negative assertion, expects the expression to be false or nil . Keep in mind that refute does not change the semantics of the given expression. In other words, the following will fail: refute { :ok , _ } = some_function_that_returns_error_tuple ( ) The code above will fail because the = operator always fails when the sides do not match and refute/2 does not change it. The correct way to write the refutation above is to use Kernel.match?/2 : refute match? ( { :ok , _ } , some_function_that_returns_error_tuple ( ) ) Examples refute age &lt; 0","ref":"Uptight.Assertions.html#refute/1","title":"Uptight.Assertions.refute/1","type":"macro"},{"doc":"Asserts value is nil or false (that is, value is not truthy). Examples refute true , &quot;This will obviously fail&quot;","ref":"Uptight.Assertions.html#refute/2","title":"Uptight.Assertions.refute/2","type":"function"},{"doc":"Asserts value1 and value2 are not within delta . This difference is exclusive, so the test will fail if the difference and the delta are equal. If you supply message , information about the values will automatically be appended to it. Examples refute_in_delta 1.1 , 1.2 , 0.2 refute_in_delta 10 , 11 , 2","ref":"Uptight.Assertions.html#refute_in_delta/4","title":"Uptight.Assertions.refute_in_delta/4","type":"function"},{"doc":"Asserts that a message matching pattern was not received (and won't be received) within the timeout period, specified in milliseconds. The pattern argument must be a match pattern. Flunks with failure_message if a message matching pattern is received. Examples refute_receive :bye Refute received with an explicit timeout: refute_receive :bye , 1000","ref":"Uptight.Assertions.html#refute_receive/3","title":"Uptight.Assertions.refute_receive/3","type":"macro"},{"doc":"Asserts a message matching pattern was not received (i.e. it is not in the current process' mailbox). The pattern argument must be a match pattern. Flunks with failure_message if a message matching pattern was received. Timeout is set to 0, so there is no waiting time. Examples send ( self ( ) , :hello ) refute_received :bye send ( self ( ) , :hello ) refute_received :hello , &quot;Oh No!&quot; ** (Uptight.AssertionError) Oh No!","ref":"Uptight.Assertions.html#refute_received/2","title":"Uptight.Assertions.refute_received/2","type":"macro"},{"doc":"Helper functions for formatting and the formatting protocols. Formatters are GenServer s specified during Uptight configuration that receive a series of events as casts. The following events are possible: {:suite_started, opts} - the suite has started with the specified options to the runner. {:suite_finished, times_us} - the suite has finished. Returns several measurements in microseconds for running the suite. See t:times_us for more information. {:module_started, test_module} - a test module has started. See Uptight.TestModule for details. {:module_finished, test_module} - a test module has finished. See Uptight.TestModule for details. {:test_started, test} - a test has started. See Uptight.Test for details. {:test_finished, test} - a test has finished. See Uptight.Test for details. {:sigquit, [test | test_module]} - the VM is going to shutdown. It receives the test cases (or test module in case of setup_all ) still running. The formatter will also receive the following events but they are deprecated and should be ignored: {:case_started, test_module} - a test module has started. See Uptight.TestModule for details. {:case_finished, test_module} - a test module has finished. See Uptight.TestModule for details. The full Uptight configuration is passed as the argument to GenServer.init/1 callback when the formatters are started. If you need to do runtime configuration of a formatter, you can only do it when you run ExUnit by using ExUnit.configure/1 or ExUnit.start/1 , and this will then be included in the options passed to the GenServer.init/1 callback.","ref":"Uptight.Assertions.Formatter.html","title":"Uptight.Assertions.Formatter","type":"module"},{"doc":"Formats filters used to constrain cases to be run. Examples iex&gt; format_filters ( [ run : true , slow : false ] , :include ) &quot;Including tags: [run: true, slow: false]&quot;","ref":"Uptight.Assertions.Formatter.html#format_filters/2","title":"Uptight.Assertions.Formatter.format_filters/2","type":"function"},{"doc":"Receives a test module and formats its failure.","ref":"Uptight.Assertions.Formatter.html#format_test_all_failure/5","title":"Uptight.Assertions.Formatter.format_test_all_failure/5","type":"function"},{"doc":"Formats time taken running the test suite. Examples iex&gt; format_times ( %{ run : 10000 , async : nil , load : nil } ) &quot;Finished in 0.01 seconds (0.00s async, 0.01s sync)&quot; iex&gt; format_times ( %{ run : 10000 , async : nil , load : 20000 } ) &quot;Finished in 0.03 seconds (0.02s on load, 0.00s async, 0.01s sync)&quot; iex&gt; format_times ( %{ run : 10000 , async : nil , load : 200_000 } ) &quot;Finished in 0.2 seconds (0.2s on load, 0.00s async, 0.01s sync)&quot; iex&gt; format_times ( %{ run : 100_000 , async : 50000 , load : 200_000 } ) &quot;Finished in 0.3 seconds (0.2s on load, 0.05s async, 0.05s sync)&quot;","ref":"Uptight.Assertions.Formatter.html#format_times/1","title":"Uptight.Assertions.Formatter.format_times/1","type":"function"},{"doc":"","ref":"Uptight.Assertions.Formatter.html#t:id/0","title":"Uptight.Assertions.Formatter.id/0","type":"type"},{"doc":"The times spent on several parts of the test suite. The following properties can be computed: sync = run - ( async || 0 ) total = run + ( load || 0 ) async is nil when there are no async tests. load is nil when the test suite is running and loading tests concurrently.","ref":"Uptight.Assertions.Formatter.html#t:times_us/0","title":"Uptight.Assertions.Formatter.times_us/0","type":"type"},{"doc":"Type wrappers for BaseN representations of binary data.","ref":"Uptight.Base.html","title":"Uptight.Base","type":"module"},{"doc":"","ref":"Uptight.Base.html#binary_to_urlsafe/1","title":"Uptight.Base.binary_to_urlsafe/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#binary_to_urlsafe!/1","title":"Uptight.Base.binary_to_urlsafe!/1","type":"function"},{"doc":"Perhaps, constructs a representation of a hex string. Example iex&gt; Uptight.Base . mk16 ( &quot;1337C0DE&quot; ) % Uptight.Result.Ok { ok : % Uptight.Base.Sixteen { encoded : &quot;1337C0DE&quot; , raw : &lt;&lt; 19 , 55 , 192 , 222 &gt;&gt; } }","ref":"Uptight.Base.html#mk16/1","title":"Uptight.Base.mk16/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#mk32/1","title":"Uptight.Base.mk32/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#mk64/1","title":"Uptight.Base.mk64/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#mk_url/1","title":"Uptight.Base.mk_url/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#mk_url!/1","title":"Uptight.Base.mk_url!/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#new/0","title":"Uptight.Base.new/0","type":"function"},{"doc":"Defensive constructor. Examples iex&gt; Uptight.Base . new ( &quot;0L/Ri9GJIG9sb2xvINGPINCy0L7QtNC40YLQtdC70Ywg0J3Qm9CeIQ==&quot; ) % Uptight.Result.Ok { ok : % Uptight.Base.SixtyFour { encoded : &quot;0L/Ri9GJIG9sb2xvINGPINCy0L7QtNC40YLQtdC70Ywg0J3Qm9CeIQ==&quot; , raw : &quot;пыщ ololo я водитель НЛО!&quot; } } iex&gt; Uptight.Base . new ( &quot;0L/Ri9GJIG9sb2xvINGPINCy0L7QtNC40YLQtdC70Ywg0J3Qm9CeIQ==&quot; ) |&gt; Uptight.Result . is_ok? ( ) true","ref":"Uptight.Base.html#new/1","title":"Uptight.Base.new/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#new!/1","title":"Uptight.Base.new!/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#raw_to_urlsafe/1","title":"Uptight.Base.raw_to_urlsafe/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#raw_to_urlsafe!/1","title":"Uptight.Base.raw_to_urlsafe!/1","type":"function"},{"doc":"See Uptight.Base.binary_to_urlsafe/1 .","ref":"Uptight.Base.html#safe/1","title":"Uptight.Base.safe/1","type":"function"},{"doc":"See Uptight.Base.binary_to_urlsafe!/1 .","ref":"Uptight.Base.html#safe!/1","title":"Uptight.Base.safe!/1","type":"function"},{"doc":"","ref":"Uptight.Base.html#t:t/0","title":"Uptight.Base.t/0","type":"type"},{"doc":"","ref":"Uptight.Base.Sixteen.html","title":"Uptight.Base.Sixteen","type":"module"},{"doc":"Positional constructor, with args in the same order as they were defined in","ref":"Uptight.Base.Sixteen.html#new/2","title":"Uptight.Base.Sixteen.new/2","type":"function"},{"doc":"","ref":"Uptight.Base.Sixteen.html#new_partial/0","title":"Uptight.Base.Sixteen.new_partial/0","type":"function"},{"doc":"","ref":"Uptight.Base.Sixteen.html#new_partial/1","title":"Uptight.Base.Sixteen.new_partial/1","type":"function"},{"doc":"","ref":"Uptight.Base.Sixteen.html#new_partial/2","title":"Uptight.Base.Sixteen.new_partial/2","type":"function"},{"doc":"","ref":"Uptight.Base.Sixteen.html#t:t/0","title":"Uptight.Base.Sixteen.t/0","type":"type"},{"doc":"","ref":"Uptight.Base.SixtyFour.html","title":"Uptight.Base.SixtyFour","type":"module"},{"doc":"Positional constructor, with args in the same order as they were defined in","ref":"Uptight.Base.SixtyFour.html#new/2","title":"Uptight.Base.SixtyFour.new/2","type":"function"},{"doc":"","ref":"Uptight.Base.SixtyFour.html#new_partial/0","title":"Uptight.Base.SixtyFour.new_partial/0","type":"function"},{"doc":"","ref":"Uptight.Base.SixtyFour.html#new_partial/1","title":"Uptight.Base.SixtyFour.new_partial/1","type":"function"},{"doc":"","ref":"Uptight.Base.SixtyFour.html#new_partial/2","title":"Uptight.Base.SixtyFour.new_partial/2","type":"function"},{"doc":"","ref":"Uptight.Base.SixtyFour.html#t:t/0","title":"Uptight.Base.SixtyFour.t/0","type":"type"},{"doc":"","ref":"Uptight.Base.ThirtyTwo.html","title":"Uptight.Base.ThirtyTwo","type":"module"},{"doc":"Positional constructor, with args in the same order as they were defined in","ref":"Uptight.Base.ThirtyTwo.html#new/2","title":"Uptight.Base.ThirtyTwo.new/2","type":"function"},{"doc":"","ref":"Uptight.Base.ThirtyTwo.html#new_partial/0","title":"Uptight.Base.ThirtyTwo.new_partial/0","type":"function"},{"doc":"","ref":"Uptight.Base.ThirtyTwo.html#new_partial/1","title":"Uptight.Base.ThirtyTwo.new_partial/1","type":"function"},{"doc":"","ref":"Uptight.Base.ThirtyTwo.html#new_partial/2","title":"Uptight.Base.ThirtyTwo.new_partial/2","type":"function"},{"doc":"","ref":"Uptight.Base.ThirtyTwo.html#t:t/0","title":"Uptight.Base.ThirtyTwo.t/0","type":"type"},{"doc":"","ref":"Uptight.Base.Urlsafe.html","title":"Uptight.Base.Urlsafe","type":"module"},{"doc":"Positional constructor, with args in the same order as they were defined in","ref":"Uptight.Base.Urlsafe.html#new/2","title":"Uptight.Base.Urlsafe.new/2","type":"function"},{"doc":"","ref":"Uptight.Base.Urlsafe.html#new_partial/0","title":"Uptight.Base.Urlsafe.new_partial/0","type":"function"},{"doc":"","ref":"Uptight.Base.Urlsafe.html#new_partial/1","title":"Uptight.Base.Urlsafe.new_partial/1","type":"function"},{"doc":"","ref":"Uptight.Base.Urlsafe.html#new_partial/2","title":"Uptight.Base.Urlsafe.new_partial/2","type":"function"},{"doc":"","ref":"Uptight.Base.Urlsafe.html#t:t/0","title":"Uptight.Base.Urlsafe.t/0","type":"type"},{"doc":"Newtype wrapper for pure binary data.","ref":"Uptight.Binary.html","title":"Uptight.Binary","type":"module"},{"doc":"Default Elixir.Uptight.Binary struct","ref":"Uptight.Binary.html#new/0","title":"Uptight.Binary.new/0","type":"function"},{"doc":"Constructor helper for piping","ref":"Uptight.Binary.html#new/1","title":"Uptight.Binary.new/1","type":"function"},{"doc":"","ref":"Uptight.Binary.html#new!/1","title":"Uptight.Binary.new!/1","type":"function"},{"doc":"","ref":"Uptight.Binary.html#un/1","title":"Uptight.Binary.un/1","type":"function"},{"doc":"","ref":"Uptight.Binary.html#t:t/0","title":"Uptight.Binary.t/0","type":"type"},{"doc":"Foldable plus.","ref":"Uptight.Fold.html","title":"Uptight.Fold","type":"module"},{"doc":"Folds by gluing the elements. Constraints in typespec are fake and don't do anything except for suggesting required typeclasses. Example iex&gt; Uptight.Result . new ( fn -&gt; Uptight.Fold . intercalate ( [ 1 , 2 , 3 ] , &quot;&quot; ) end ) |&gt; Uptight.Result . is_err? ( ) true # iex&gt; Uptight.Fold.intercalate(Witchcraft.Functor.map([1,2,3], &amp;Uptight.Add.new/1), 1) # 9 iex&gt; Uptight.Fold . intercalate ( [ ] , 1 ) 0 iex&gt; Uptight.Fold . intercalate ( [ Uptight.Text . new! ( &quot;.&quot; ) , Uptight.Text . new! ( &quot;a.out&quot; ) ] , Uptight.Text . new! ( &quot;/&quot; ) ) % Uptight.Text { text : &quot;./a.out&quot; } iex&gt; Uptight.Fold . intercalate ( [ Uptight.Text . new! ( &quot;.&quot; ) ] , Uptight.Text . new! ( &quot;lol nvm&quot; ) ) % Uptight.Text { text : &quot;.&quot; }","ref":"Uptight.Fold.html#intercalate/2","title":"Uptight.Fold.intercalate/2","type":"function"},{"doc":"Inserts glue between each pair of elements. Constraints in typespec are fake and don't do anything except for suggesting required typeclasses. Example iex&gt; Uptight.Fold . intersperse ( [ 1 , 2 , 3 ] , &quot;the power of elixir&quot; ) [ 1 , &quot;the power of elixir&quot; , 2 , &quot;the power of elixir&quot; , 3 ] iex&gt; Uptight.Fold . intersperse ( [ Uptight.Text . new! ( &quot;.&quot; ) , Uptight.Text . new! ( &quot;a.out&quot; ) ] , Uptight.Text . new! ( &quot;/&quot; ) ) [ % Uptight.Text { text : &quot;.&quot; } , % Uptight.Text { text : &quot;/&quot; } , % Uptight.Text { text : &quot;a.out&quot; } ] iex&gt; Uptight.Fold . intersperse ( [ Uptight.Text . new! ( &quot;.&quot; ) ] , Uptight.Text . new! ( &quot;lol nvm&quot; ) ) [ % Uptight.Text { text : &quot;.&quot; } ]","ref":"Uptight.Fold.html#intersperse/2","title":"Uptight.Fold.intersperse/2","type":"function"},{"doc":"","ref":"Uptight.Fold.html#right_glued/2","title":"Uptight.Fold.right_glued/2","type":"function"},{"doc":"Alternative Either. Differences from Alage Either: Overloaded new that takes a nullary function, runs it and if it raises an error, it returns Err holding Uptight.Trace, it returns Ok otherwise. As data, not biased neither towrards Ok nor Err, whereas Algae version is biased towards Right: https://github.com/witchcrafters/algae/blob/067e2b0a02c5c0c4183051807dfa733e2ee43fe4/lib/algae/either.ex#L140. As operation, biased neither towards Ok nor Err (unlike Algae version, which is biased towards Left). Thus, Result instances adhere to all the typeclass laws.","ref":"Uptight.Result.html","title":"Uptight.Result","type":"module"},{"doc":"","ref":"Uptight.Result.html#cont/2","title":"Uptight.Result.cont/2","type":"function"},{"doc":"","ref":"Uptight.Result.html#cont_end/1","title":"Uptight.Result.cont_end/1","type":"function"},{"doc":"","ref":"Uptight.Result.html#from_ok/1","title":"Uptight.Result.from_ok/1","type":"function"},{"doc":"","ref":"Uptight.Result.html#is_err?/1","title":"Uptight.Result.is_err?/1","type":"function"},{"doc":"","ref":"Uptight.Result.html#is_ok?/1","title":"Uptight.Result.is_ok?/1","type":"function"},{"doc":"","ref":"Uptight.Result.html#new/0","title":"Uptight.Result.new/0","type":"function"},{"doc":"Run failable function, capturing return value into Ok and a runtime error into Err. Examples iex&gt; Uptight.Result . new ( fn ( ) -&gt; :erlang . system_flag ( :backtrace_depth , 0 ) ; raise &quot;oopsie&quot; end ) |&gt; Uptight.Result . is_err? ( ) true iex&gt; Uptight.Result . new ( fn ( ) -&gt; :erlang . system_flag ( :backtrace_depth , 20 ) ; raise &quot;is_err!&quot; end ) |&gt; Uptight.Result . is_err? ( ) true iex&gt; Uptight.Result . new ( fn ( ) -&gt; 42 end ) % Uptight.Result.Ok { ok : 42 } iex&gt; Uptight.Result . new ( fn ( ) -&gt; 42 end ) |&gt; Uptight.Result . is_ok? ( ) true iex&gt; Uptight.Result . new ( fn ( ) -&gt; 42 end ) |&gt; Uptight.Result . is_err? ( ) false","ref":"Uptight.Result.html#new/1","title":"Uptight.Result.new/1","type":"function"},{"doc":"","ref":"Uptight.Result.html#new_ok/0","title":"Uptight.Result.new_ok/0","type":"function"},{"doc":"","ref":"Uptight.Result.html#t:t/0","title":"Uptight.Result.t/0","type":"type"},{"doc":"","ref":"Uptight.Result.Err.html","title":"Uptight.Result.Err","type":"module"},{"doc":"Default Elixir.Uptight.Result.Err struct. Value defaults to :%{}.","ref":"Uptight.Result.Err.html#new/0","title":"Uptight.Result.Err.new/0","type":"function"},{"doc":"Helper for initializing struct with a specific value","ref":"Uptight.Result.Err.html#new/1","title":"Uptight.Result.Err.new/1","type":"function"},{"doc":"","ref":"Uptight.Result.Err.html#t:t/0","title":"Uptight.Result.Err.t/0","type":"type"},{"doc":"","ref":"Uptight.Result.Ok.html","title":"Uptight.Result.Ok","type":"module"},{"doc":"Default Elixir.Uptight.Result.Ok struct. Value defaults to nil.","ref":"Uptight.Result.Ok.html#new/0","title":"Uptight.Result.Ok.new/0","type":"function"},{"doc":"Helper for initializing struct with a specific value","ref":"Uptight.Result.Ok.html#new/1","title":"Uptight.Result.Ok.new/1","type":"function"},{"doc":"","ref":"Uptight.Result.Ok.html#t:t/0","title":"Uptight.Result.Ok.t/0","type":"type"},{"doc":"Newtype for textual data. It does what you expect, except it has one peculiarity: map just applies function to the underlying binary string as is right_fold and other folds from Foldable iterate through UTF-8 characters This behaviour probably should be unified to work over UTF-8 characters one way or another and a custom class Newtype should be devised to provide naive fmap functionality.","ref":"Uptight.Text.html","title":"Uptight.Text","type":"module"},{"doc":"Default Elixir.Uptight.Text struct","ref":"Uptight.Text.html#new/0","title":"Uptight.Text.new/0","type":"function"},{"doc":"Defensive constructor. Examples iex&gt; Uptight.Text . new ( &lt;&lt; 5555 &gt;&gt; ) |&gt; Uptight.Result . is_err? ( ) true iex&gt; Uptight.Text . new ( &lt;&lt; 322 &gt;&gt; ) % Uptight.Result.Ok { ok : % Uptight.Text { text : &quot;B&quot; } } iex&gt; Uptight.Text . new ( &lt;&lt; 228 &gt;&gt; ) |&gt; Uptight.Result . is_err? ( ) true iex&gt; Uptight.Text . new ( &quot;hello&quot; ) |&gt; Uptight.Result . from_ok ( ) |&gt; Witchcraft.Foldable . right_fold ( &quot;&quot; , fn x , acc -&gt; x &lt;&gt; acc end ) &quot;olleh&quot;","ref":"Uptight.Text.html#new/1","title":"Uptight.Text.new/1","type":"function"},{"doc":"Offensive constructor.","ref":"Uptight.Text.html#new!/1","title":"Uptight.Text.new!/1","type":"function"},{"doc":"","ref":"Uptight.Text.html#un/1","title":"Uptight.Text.un/1","type":"function"},{"doc":"","ref":"Uptight.Text.html#t:t/0","title":"Uptight.Text.t/0","type":"type"},{"doc":"Defdata for exception along with stacktrace.","ref":"Uptight.Trace.html","title":"Uptight.Trace","type":"module"},{"doc":"","ref":"Uptight.Trace.html#arity_or_args_to_int/1","title":"Uptight.Trace.arity_or_args_to_int/1","type":"function"},{"doc":"","ref":"Uptight.Trace.html#location_to_map/1","title":"Uptight.Trace.location_to_map/1","type":"function"},{"doc":"Positional constructor, with args in the same order as they were defined in","ref":"Uptight.Trace.html#new/2","title":"Uptight.Trace.new/2","type":"function"},{"doc":"","ref":"Uptight.Trace.html#new_partial/0","title":"Uptight.Trace.new_partial/0","type":"function"},{"doc":"","ref":"Uptight.Trace.html#new_partial/1","title":"Uptight.Trace.new_partial/1","type":"function"},{"doc":"","ref":"Uptight.Trace.html#new_partial/2","title":"Uptight.Trace.new_partial/2","type":"function"},{"doc":"","ref":"Uptight.Trace.html#stacktrace_entry_to_map/1","title":"Uptight.Trace.stacktrace_entry_to_map/1","type":"function"},{"doc":"","ref":"Uptight.Trace.html#stacktrace_to_map/1","title":"Uptight.Trace.stacktrace_to_map/1","type":"function"},{"doc":"","ref":"Uptight.Trace.html#t:t/0","title":"Uptight.Trace.t/0","type":"type"},{"doc":"Raised to signal an assertion error.","ref":"Uptight.AssertionError.html","title":"Uptight.AssertionError","type":"exception"},{"doc":"Indicates no meaningful value for a field.","ref":"Uptight.AssertionError.html#no_value/0","title":"Uptight.AssertionError.no_value/0","type":"function"},{"doc":"Raised to signal multiple errors happened in a test case.","ref":"Uptight.MultiError.html","title":"Uptight.MultiError","type":"exception"}]